@@ -4,6 +4,9 @@
 #include "grib_api.h"
 #include "narray.h"
 
+#ifndef NARRAY_BIGMEM
+typedef int na_shape_t;
+#endif
 
 #define MAX_VALUE_LENGTH 1024
 
@@ -11,7 +14,7 @@
 static void
 check_error(int code)
 {
-  if (code) rb_raise(rb_eRuntimeError, grib_get_error_message(code));
+  if (code) rb_raise(rb_eRuntimeError, "%s", grib_get_error_message(code));
 };
 
 
@@ -681,7 +684,7 @@ rg_message_get_value(int argc, VALUE *argv, VALUE self)
 	  ret = LONG2NUM(l);
 	}	  
       } else {
-	int shape[1];
+	na_shape_t shape[1];
 	struct NARRAY *nary;
 	shape[0] = len;
 	VALUE rnary = na_make_object(NA_LINT, 1, shape, cNArray);
@@ -698,7 +701,7 @@ rg_message_get_value(int argc, VALUE *argv, VALUE self)
 	if (grib_get_double(message->handle, name, &value) == GRIB_SUCCESS)
 	  ret = rb_float_new(value);
       } else {
-	int shape[1];
+	na_shape_t shape[1];
 	struct NARRAY *nary;
 	shape[0] = len;
 	VALUE rnary = na_make_object(NA_DFLOAT, 1, shape, cNArray);
@@ -730,7 +733,7 @@ rg_message_get_data(VALUE self)
   double *lon, *lat, *value;
   VALUE na_lon, na_lat, na_value;
   struct NARRAY *nary;
-  int shape[1];
+  na_shape_t shape[1];
   shape[0] = np;
   na_lon = na_make_object(NA_DFLOAT, 1, shape, cNArray);
   GetNArray(na_lon, nary);
@@ -757,7 +760,7 @@ rg_message_get_data(VALUE self)
 
 void Init_grib()
 {
-  rb_require("narray");
+  //  rb_require("narray");
 
   id_init = rb_intern("init");
 
